#
# spec file for package psmisc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without apparmor

Name:           psmisc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  dejagnu
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  glibc-devel
BuildRequires:  glibc-gconv-modules-extra
BuildRequires:  libselinux-devel
BuildRequires:  linux-glibc-devel >= 4.12
BuildRequires:  ncurses-devel
BuildRequires:  netcat-openbsd
%if %{with apparmor}
BuildRequires:  pkgconfig(libapparmor)
%endif
URL:            https://gitlab.com/psmisc/psmisc/
Version:        23.7
Release:        1.1
Provides:       ps:/usr/bin/killall
Summary:        Utilities for managing processes on your system
License:        GPL-2.0-or-later
Group:          System/Monitoring
Source:         https://gitlab.com/%{name}/%{name}/-/archive/v%{version}/%{name}-v%{version}.tar.bz2
Patch0:         %{name}-v%{version}.dif
Patch1:         0001-killall,pstree-use-clock_gettime-not-uptime.patch
Patch2:         %{name}-22.21-pstree.patch
# PATCH-ADD-SUSE boo#908068, boo#1046237, boo#1046237
# https://gitlab.com/bitstreamout/psmisc/tree/mountinfo
Patch3:         0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch

%define have_peekfd %ix86 x86_64 ppc ppc64 ppc64le %arm mipsel m68k aarch64

%description
The psmisc package contains utilities for managing processes on your
system: pstree, killall and fuser.  The pstree command displays a tree
structure of all of the running processes on your system.  The killall
command sends a specified signal (SIGTERM if nothing is specified) to
processes identified by name.  The fuser command identifies the PIDs of
processes that are using specified files or filesystems.

%lang_package

%prep
%setup -q -n %{name}-v%{version}
%patch -P 1 -p0 -b .uptime
%patch -P 2 -p0 -b .pstree
%patch -P 3 -p0 -b .mntinf
%patch -P 0 -p0 -b .p0

%build
grep -h src/ po/*.po|\
 sed -r 's/^#: //'|\
 tr ' ' '\n'|\
 sort -t : -k1,1 -u|\
 sed -r 's/:[0-9]+$//' > po/POTFILES.in
echo %version > .tarball-version
autoreconf -fi
CFLAGS="-D_GNU_SOURCE -D_DEFAULT_SOURCE ${RPM_OPT_FLAGS} -pipe -fPIE"
CXXFLAGS="$CFLAGS"
LDFLAGS=-pie
CC=gcc
export CFLAGS CXXFLAGS LDFLAGS CC
%configure	--disable-rpath \
	--with-gnu-ld		\
	%{?with_apparmor:--enable-apparmor} \
	--enable-selinux
make %{?_smp_mflags} CFLAGS="$CFLAGS" "CC=$CC"

%check
make check

%install
make DESTDIR=%{buildroot} install
%if 0%{?suse_version} < 1550
mkdir -p %{buildroot}/bin/
ln -sf %{_bindir}/fuser %{buildroot}/bin/
%endif
%ifnarch %have_peekfd
rm -f %{buildroot}%{_mandir}/man1/peekfd.1*
%endif
%find_lang psmisc

%files
%defattr (-,root,root,755)
%license COPYING
%if 0%{?suse_version} < 1550
/bin/fuser
%endif
%{_bindir}/fuser
%{_bindir}/killall
%ifarch %have_peekfd
%{_bindir}/peekfd
%endif
%{_bindir}/prtstat
%{_bindir}/pslog
%{_bindir}/pstree
%{_bindir}/pstree.x11
%{_mandir}/man1/fuser.1*
%{_mandir}/man1/killall.1*
%ifarch %have_peekfd
%{_mandir}/man1/peekfd.1*
%endif
%{_mandir}/man1/prtstat.1*
%{_mandir}/man1/pslog.1*
%{_mandir}/man1/pstree.1*

%files lang -f %{name}.lang

%changelog
* Mon May 27 2024 Dr. Werner Fink <werner@suse.de>
- Update to 23.7
  * build-sys: Make disable-statx work
  * fuser: Fallback to stat() if no statx() Debian 1030747 #48
  * fuser: silently ignore EACCES when scanning proc directories
  * killall: small formatting fixes Debian #1037231
  * pstree: Do not assume root PID #49
  * pslog: include config.h #51 !36
  * misc: Update gettext to 0.21
- Add patch from upstream 0001-killall,pstree-use-clock_gettime-not-uptime.patch
- Port the patches
  * 0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
  * psmisc-22.21-pstree.patch
- Port patch psmisc-v23.6.dif and rename it to psmisc-v23.7.dif
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Oct 23 2023 Dr. Werner Fink <werner@suse.de>
- Fix version at configure time as there was no .tarball-version
* Thu Feb 16 2023 Ludwig Nussel <lnussel@suse.de>
- allow to switch off Apparmor support via bcond
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Tue Dec 13 2022 Dr. Werner Fink <werner@suse.de>
- Update to 23.6:
  * buildsys: Fix DEJAGNU work-around Debian #1015089
  * killall: Use kill if pidfd_send_signal fails Debian #1015228
  * fuser: Do not mention nonexistent - reset option #42
  * fuser: Use modern statn where possible
  * pstree: Better AppArmor support !30
  * killall: Check truncated names !28
  * killall: Use openat and pidfd_send_signal #37
  * killall: Don't check paths of sockets #35
  * pstree: Check for process with show_parents #38
  * pstree: Don't disable compaction with show pgids #34
  * pstree: Fix storage leak !29
- Enable new apparmor support
- Remove patch now upstream
  0002-Use-new-statx-2-system-call-to-avoid-hangs-on-NFS.patch
- Port patch psmisc-22.21-pstree.patch
- Port patch psmisc-v23.4.dif which now becomes psmisc-v23.6.dif
- Merge patch socket-fix.patch with ported patch
  0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
* Fri Nov 25 2022 Dr. Werner Fink <werner@suse.de>
- Add patch socket-fix.patch
  * Add test to check for named sockets as file as well as on mounts
  * Fix code to find named sockets
- The former test requires nc at build aka netcat from openbsd to
  create a named socket on the fly
* Wed Feb 23 2022 Dr. Werner Fink <werner@suse.de>
- Change patch 0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
  * Add a fallback if the system call name_to_handle_at() is
    not supported by the used file system.
* Tue Feb  1 2022 Dr. Werner Fink <werner@suse.de>
- Change patch 0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
  * Determine the namespace of a process only once to speed
    up the parsing of fdinfo (bsc#1194172).
- Adopt patch 0002-Use-new-statx-2-system-call-to-avoid-hangs-on-NFS.patch
* Thu Jan 20 2022 Dr. Werner Fink <werner@suse.de>
- Update to 23.4:
  * killall: Dynamically link to selinux and use security attributes
  * pstree: Do not crash on missing processes !21
  * pstree: fix layout when using -C !24
  * pstree: add time namespace !25
  * pstree: Dynamically link to selinux and use attr
  * fuser: Get less confused about duplicate dev_id !10
  * fuser: Only check pathname on non-block devices !31
- Rebase 0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
- Rebase 0002-Use-new-statx-2-system-call-to-avoid-hangs-on-NFS.patch
- Port psmisc-22.21-pstree.patch
- Delete psmisc-v23.3-selinux.patch as not needed anymore
- Rename psmisc-v23.3.dif which is now psmisc-v23.4.dif with correct offsets
* Thu May 20 2021 Dr. Werner Fink <werner@suse.de>
- Do not change CAP within spec file (boo#1186258)
* Fri May  7 2021 Dr. Werner Fink <werner@suse.de>
- Change patch 0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
  * Fix bsc#1185208 to make private mount namespaces work as well
    as to distinguish NFS mounts from same remote device share.
* Fri Mar  5 2021 Dr. Werner Fink <werner@suse.de>
- Change patch 0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
  * Fix bsc#1178407: fuser does not show open kvm storage image files
    such as qcow2 files. Patch from Ali Abdallah <ali.abdallah@suse.com>
* Thu Jan 14 2021 Dr. Werner Fink <werner@suse.de>
- Now with 23.3 peekfd is build even for aarch64
* Thu Jan 14 2021 Dr. Werner Fink <werner@suse.de>
- Rework 0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
  and split off the patch psmisc-v23.3-selinux.patch
- Rework 0002-Use-new-statx-2-system-call-to-avoid-hangs-on-NFS.patch
- New patch psmisc-v23.3-selinux.patch
- Rename patch psmisc-v23.2.dif which is now psmisc-v23.3.dif
* Thu Dec 31 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 23.3:
  * killall: check also truncated 16 char comm names Debian
  * fuser: Return early if have nulls
  * peekfd: Add support for ARM64
  * pstree: Add color by age
  * fuser: Use larger inode sizes
- Rebase 0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
- Rebase 0002-Use-new-statx-2-system-call-to-avoid-hangs-on-NFS.patch
- Rebase psmisc-22.21-pstree.patch
* Fri Oct 16 2020 Ludwig Nussel <lnussel@suse.de>
- prepare usrmerge (boo#1029961)
* Mon Apr 27 2020 Dr. Werner Fink <werner@suse.de>
- Modify patch 0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
  * Allow not unique mounts as well as not unique mountpoint (bsc#1170247)
* Thu Sep 19 2019 Ludwig Nussel <lnussel@suse.de>
- Do not recommend lang package. The lang package already has a
  supplements.
* Fri Nov 30 2018 Dr. Werner Fink <werner@suse.de>
- Modify patch 0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
  * Always initialize head of simple linked list (bsc#1098697)
  * stat(2) on binary does not see subvol dev
* Wed Nov 14 2018 Dr. Werner Fink <werner@suse.de>
- Modify patch 0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
  to handle sub volumes of the btrFS (bsc#1112780)
* Mon Nov  5 2018 Dr. Werner Fink <werner@suse.de>
- Modify patch 0002-Use-new-statx-2-system-call-to-avoid-hangs-on-NFS.patch
  to support older systems with statx kernel support
* Fri Nov  2 2018 Dr. Werner Fink <werner@suse.de>
- Modify patch 0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
  to respect autofs as well as afs file system
- Add patch 0002-Use-new-statx-2-system-call-to-avoid-hangs-on-NFS.patch
  to use statx(2) system call since kernel 4.12. Now it is possible
  to avoid sync with remote file servers as well as trigger autofs
  mounts due stat(x) calls.
* Tue Oct 23 2018 Dr. Werner Fink <werner@suse.de>
- Support also btrFS entries in mountinfo, that is use stat(2) to
  determine the device of the mounted subvolume (bsc#1098697, bsc#1112780)
* Mon Oct 22 2018 Dr. Werner Fink <werner@suse.de>
- Update to version 23.2
  * misc: Command names increased from 16 to 64 characters
  * buildsys: signals.c depends on signames.h !16
  * docs: Fix fuser.1 groff errors Debian #900225
  * killall: look at all namespaces by default
  * killall: Fix -INT option parsing #11
  * killall: ignore -n 0 #15
  * killall: another crack at fixing getopt #12 #13
  * peekfd: Attach to all threads option !15
  * pslog: Define PATH_MAX if required Debian:#905797
- Modify patch 0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
- Remove patches now upstream solved
  * psmisc-23.0-killall-signals.patch
  * psmisc-23.0-killall.patch
- Modify and rename patch psmisc-23.0.dif which now becomes psmisc-v23.2.dif
* Mon Sep 17 2018 Dr. Werner Fink <werner@suse.de>
- Add COPYING to file list as otherwise a required fix does not
  reach anything
* Fri Jun 22 2018 werner@suse.de
- Modify patch 0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
  to make fuser option -m <block_device> work even with mountinfo
  (bsc#1098697)
* Thu May 17 2018 werner@suse.de
- Modify patch 0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
  to let fuser -m also work for private mounts as well (boo#1093665)
* Fri Oct 13 2017 werner@suse.de
- Modify patch 0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
  to run even on older kernels missing mnt_id tag in fdinfo
* Mon Sep 18 2017 werner@suse.de
- Add patch psmisc-23.0-killall-signals.patch to fix boo#1058990
  by prior scanning for signal names in the arguments of killall
* Thu Jul  6 2017 werner@suse.de
- Update patch
  0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
* Wed Jul  5 2017 werner@suse.de
- Remove patches
  * psmisc-22.21-lessnfs.patch
  * psmisc-22.21-mntpt.patch
  * psmisc-23.0-net.patch
- Add patch
  0001-Use-mountinfo-to-be-able-to-use-the-mount-identity.patch
  from https://gitlab.com/bitstreamout/psmisc/tree/mountinfo
  which is a heavily rework fuser used on NFS
  * Use mountinfo to be able to use the mount identity
    which allows to distinguish different mounts with the
    same device number as it happens with NFS shares.
  * Smaller cleanup as support of chroot environments
    and older systems.
  * Add support for name_to_handle_at() system call to
    get the real mount ID for each file
- Use test suite of psmisc in %%check rpm section
* Wed Jun 28 2017 werner@suse.de
- Add patch psmisc-23.0-net.patch to reenable network support
  broken to my own upstream commit
* Wed Jun 28 2017 werner@suse.de
- Add patch psmisc-23.0-killall.patch to remove left over debug
  output in killall utility (boo#1046237)
* Tue Jun 20 2017 werner@suse.de
- Update to version 23.0
  * killall: Fix process age race condition !11 Debian #822861
  * killall: only use scope of current namespace by default
  * killall: better parsing of command names
  * pstree: add cgroup namespaces !10
  * peekfd: Help give long options too !5
  * killall: correctly report when 32+ procs match !8
  * prtat: Remove duplicate options in man page !3 Debian #846387
  * pslog: New program to check what logs are open merge !1
  * fuser: increase path length for octal escaping SF [#37]
  * Make usage of linked lists of devices found in
    /proc/self/mountinfo optional
  * Make timeout() in timeout.c work with shared mmap to
    reduce the load due write/read the stat buffers
  * Add list_sort() to lists.h to be able to sort lists
  * fuser: Fixed typo for  -M flag. Debian #740275
  * pstree: by default doesn't show threadnames, use -t to show
    as it disables compaction. SF [#33] Debian #815902
  * pstree: Removed need for PATH_MAX Debian #750405
  * pstree: ignores disappeared processes. SF [#34]
  * killall: -o and -y work with -r flags. SF [#64]
  * m4/gettext.m4: Upgrade to gettext-0.19.4.
  * m4/iconv.m4: Upgrade to gettext-0.19.4.
  * m4/lib-ld.m4: Upgrade to gettext-0.19.4.
  * m4/lib-link.m4: Upgrade to gettext-0.19.4.
  * m4/lib-prefix.m4: Upgrade to gettext-0.19.4.
  * m4/nls.m4: Upgrade to gettext-0.19.4.
  * m4/po.m4: Upgrade to gettext-0.19.4.
  * m4/progtest.m4: Upgrade to gettext-0.19.4.
  * configure.ac (AM_GNU_GETTEXT_VERSION): Bump to 0.19.4.
- Make it build, that is create a po/POTFILES.in
- Remove obsolete patches
  * psmisc-22.21-boo908063.patch
  * psmisc-22.12-tigetstr.patch
  * psmisc-22.21-upstream.patch
  * psmisc-git-3638cc55b4d08851faba46635d737b24d016665b.patch
- Rename patch psmisc-22.21.dif which becomes psmisc-23.0.dif
- Make /bin/fuser a symblic link of /usr/bin/fuser (boo#1029973)
- Last revision was 78
* Tue Jun 20 2017 werner@suse.de
- Modify psmisc-22.21.dif to enforce the usage of `m' flag in
  sscanf() instead of `a' for allocation. Also avoid to small
  buffers and include sys/sysmacros.h for makedev macro.
- Add the patch psmisc-22.21-lessnfs.patch to support device
  files of mount points as well (boo#1044638)
- Add the patch psmisc-22.21-mntpt.patch to do strinfg comparision
  only for NFS shares
* Thu May 21 2015 schwab@suse.de
- Replace negative list %%nopeek with positive list %%have_peekfd
* Tue Mar 24 2015 werner@suse.de
- Add patch psmisc-22.21-boo908063.patch to avoid to close files
  which are never open (boo#908063)
* Thu Apr 24 2014 ro@suse.de
- add patch to fix fuser -M option active all the time (bnc#874983)
  psmisc-git-3638cc55b4d08851faba46635d737b24d016665b.patch
* Mon Mar 24 2014 werner@suse.de
- Update to version 22.21
  * Missing comma in fuser(1) added Debian #702391
  * pstree uses COLUMN env variable Debian #717017
  * pstree shows proper thread names SF Bug#57
  * pstree shows namespace options SF Patch#30
  * killall.1 minor fixes SF Bug#59
  * peekfd for m68k SF Patch#31
  * Fixing some derefefed pointers SF Patch#32
  * Minor typos in man pages SF Bug#61 Bug#60
  * fuser -m and -M flags work either way Debian #606178
- Remove patch
  psmisc-22.20-pstree.patch as now part of upstream
  peekfd-m68k.patch as now part of upstream
- Port the patches
  psmisc-22.20-upstream.patch which becomes psmisc-22.21-upstream.patch
  psmisc-22.20.dif which becomes psmisc-22.21.dif
  psmisc-22.12-pstree.patch which becomes psmisc-22.21-pstree.patch
* Wed Oct 23 2013 p.drouand@gmail.com
- Remove %%fillup_prereq %%insserv_prereq PreReq; package provides
  neither sysconfigfile or sysvinit script
- Use %%lang_package instead of define a lang subpackage manually
- Use %%configure instead of ./configure
- Don't define CC and CXX flags manually
- Remove redundant %%clean section
* Wed Oct  9 2013 schwab@suse.de
- peekfd-m68k.patch: Port peekfd to m68k
* Sat Feb  9 2013 schwab@suse.de
- peekfd hasn't been ported to aarch64 yet
* Tue Dec 18 2012 werner@suse.de
- Update to version 22.20 + upstream patch
  * Make usage of linked lists of devices found in
    /proc/self/mountinfo optional
  * Make timeout() in timeout.c work with shared mmap to
    reduce the load due write/read the stat buffers
  * Add list_sort() to lists.h to be able to sort lists
  * pstree sorts properly on names Debian #682014
  * fuser -m regresion fixed SF #3559232, thanks to hanpt
  * pstree finds orphaned processes SF#3537508
  * fuser finds unix sockets again SF #3502649
  * pstree finds pid 0 stops looping Debian #687829
  * killall with no args exits again SF #3536526
  * Added AC_CANONICAL_TARGET for target_os Debian #673485
  * sed doesn't have [0-9]+ replace with [0-9][0-9]*
  * assert in killall triggered for small lifetimes Debian #628617
  * killall MAX_NAMES off by one Debian #677428
  * Removed remaining parts of pidof
  * fuser uses correct timeout_stat define Debian #661723
  * fuser is not compiled on hurd-i386 Debian #673485
  * No TEXTRELS in src/lists built as PIE on x86
  * Fake pstree root for kernels with hidepid turned on
  * More fixes for Cygwin SF Patch #3511920
  * pstree can show PGIDs SF Patch #3471056
- This should fix the bug reported by Madhu
* Tue Mar 13 2012 werner@suse.de
- Submit ASCII null fix in pstree upsrtream
- Submit support for static background process for stat system call
  upstream
- Rebuild package with upstream patches
* Mon Feb 27 2012 werner@suse.de
- Update to version 22.16
  * Use strncpy for COMM_LEN and make it 18 characters to cover
    brackets in name.
  * don't change COMM_LEN, it breaks matching long commands
    Debian #661145
  * Enable some harden AM_CFLAGS by default, use configure option
  - -disable-harden-flags to not use it.
  * Use ENOENT not EBADE for FreeBSD Debian #631566
  * Fix prstat typos
  * Stop zombies by using waitpid Ubuntu #876387 by Peter Holik, SF#3429674
  * Fixed minor older/younger typo in killall.1 thanks to Maikel Linke
  * Correct defines for timeout in configure.ac
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Oct 11 2011 werner@suse.de
- Use __builtin___strcpy_ instead of __builtin___strcpy_chk to avoid
  trouble with char path[0] tag in struct handle (bnc#723304)
* Fri Oct  7 2011 werner@suse.de
- Make main fuser process more robust against broken pipe and check
  for helper process within a SIGCHLD handler
* Wed Oct  5 2011 werner@suse.de
- Handle internal size of structure stat by including config.h
  to avoid size missmatch during copy result back (bnc#720882)
* Mon Oct  3 2011 mmarek@suse.cz
- Fix segfault in pstree, patch by Tetsuo Handa (bnc#718915).
* Wed Sep 28 2011 coolo@suse.com
- back out the timeout patch, it breaks fuser on i586 completely
  (bnc#720882)
* Mon Sep 12 2011 werner@suse.de
- Update to pre version 22.15
  + Really apply patch for SF#31110178 RH#651794
  + Conditionally use fork before stat calls
  + Patch from Corrina Vinschen for compiling on cygwin
  + Remove doubled content in src/lists.h
  + Add another 2 for thread brackets in pstree.c
- Change fork before stat calls to be in best case a second process
  using two pipes for bidirectional communication with main.
* Tue Jun 21 2011 werner@suse.de
- Update to version 22.14:
  + Fix file descriptor as weel as memory leaks in fuser
  + Strip @ symbol from file names read from /proc/net/unix
  + Above 2 changes close openSuSE bugs #536209, #529520, and #417841
    and provided by Werner Fink
  + Applied patch from Werner Fink to avoid stat(2) on NFS mounts
  + Zeros process group memory - Patch by jgorig SF#3152925 RH#666213
  + fuser -m -s flags work - Patch by jgorig SF#31110178 RH#651794
  + fuser silent if /proc/swaps not available SF#3072134
  + ppc 64 support for peekfd by jgorig SF#3166444
  + jiffies now ULL in killall SF#3138538
  + pstree can show parents of a process. Patch supplied by Curtis
    Hawthorne SF#3135157
  + killall creates right size buffer instead of MAX_PATH Debian #623425
  + check for /proc/$$/stat not /proc/self/stat which is not available
    on hurd platforms. Same Debian bug as above
  + fuser understands IPv6 addresses, removed comment in fuser.1 that it
    doesn't Debian #609904
  + fuser -k only returns 0 if you kill something.
  + fuser doesn't complain if /proc/#/fd disappears SF#3310990
* Tue Feb  8 2011 werner@suse.de
- Now use /proc/self/mountinfo to minimize the needs of running
  stat(2) system calls.  The remaining stat(2) system calls are
  wrapped by an timeout function.
* Fri Oct 15 2010 werner@suse.de
- Add fix from upstream for a crash in peekfd
* Sun Sep 19 2010 vuntz@opensuse.org
- Update to version 22.13:
  + configure patch for x86_64 properly applied sf#3029302.
  + patch configure so pt_regs isn't used on SuperH. deb#588986
  + Fixed configure.ac so only mipsel not mips compiles peekfd
- Remove part of psmisc-22.12.dif that is upstream.
- Remove AutoReqProv: it's default now.
* Tue Jul 13 2010 werner@suse.de
- Update to psmisc-22.12
  * In fuser, switched the ipv6 and ipv4 checks around Debian #581604
  * peekfd configure patch for x86_64 SF#2986027
  * peekfd works with ARM and MIPS thanks to patch by Arnaud Patard
  * peekfd off-by-one patch applied SF#1948351
  * pstree -a doesn't segfault on grsec kernels Debian #588152
  * Another attempted at killall -SIGNAME Debian #573924
  * fuser -k -m ... won't kill itself Debian #562767
  * fuser -NAME fixed SF #2924691, Debian #563388, Gentoo #297423
  * Added locale.h include for killall on non NLS SF #2922163
  * Reversed normal file fuser -k check Debian #563387
  * short option l returned in fuser Debian #539087
  * long options terminated with 0s Debian #551833
  * fuser only kills normal processes, patch thanks to Erik Li SF# 2892724
  * New fuser -M if you REALLY want mount points, patch thanks to
    Jeremie LE HEN SF#2899709
  * Fixed killall options for VTALRM and ILL Debian #559011
  * pstree -a does not compact threads Debian #525632
  * new program prtstat which prints contents of /proc/<pid>/stat
    Debian #281706
  * killall restricts by date. Thanks to George Danchev Debian #544657
  * long options terminated in pstree too to stop segfault
  * Re-worked fuser getopt again so -KILL options work Gentoo #297423
  * Fix off-by-one overflow in pstree SF# 2832375
  * Applied patch from Kari Hautio for lazy umount'ed filesystems SF#2545632
  * Applied patch from Anonymous SF submitter to fix killall -l
    Fixes SF#2002570
  * fuser will print mounts,nfs exports and swaps with -v Debian #356655
    and SF#533958
  * pstree and fuser have long options Debian #517412
  * Fixed pstree -a off-by-one error in buffer, Debian #536243
  * Changed configure.ac to not use CXX SF# 2789801
* Tue Jul  6 2010 bg@novell.com
- peekfd is not available on hppa
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Thu Mar  4 2010 ro@suse.de
- fix overflow crash in pstree: add 2 to COMM_LEN for {...}
  brackets for threads
* Sun Dec  6 2009 jengelh@medozas.de
- enable parallel building
- do not package peekfd on SPARC (it is not built)
* Mon Oct 12 2009 werner@suse.de
- Detect current cwd to be able to compare local files (bnc#540927)
* Fri Oct  9 2009 werner@suse.de
- Yet an other fix for NFS based file detection in fuser
* Fri Oct  9 2009 aj@suse.de
- fix pstree -a crash (bnc#545265) with patch backported from 22.8
  by Björn Voigt <bjoern@cs.tu-berlin.de>.
* Thu Sep 10 2009 werner@suse.de
- For future use fix fd leak reported by  David Binderman (bnc#536209)
* Mon Aug 10 2009 werner@suse.de
- Close file descriptor leak (bnc#529520)
* Fri Jul 10 2009 jansimon.moeller@opensuse.org
- Add ARM to nopeek
* Mon May 25 2009 werner@suse.de
- Remove oldfuser from file list
* Mon May 11 2009 werner@suse.de
- Update to psmisc-22.7
  * Updated Polish, Russian, Swedish and Indonesian PO files
  * Changed fuser.1 so signal is SIGNAL to reduce confusion about wether
    or not it is a parameter Debian #517413
  * fuser.1 references pkill(1) Debian #517414
  * Added Chinese (traditional) PO file
  * Updated Russian PO file
  * Clarified -m and -c for fuser Debian #467289
  * Patch from Arnaud Giersch to fix udp ports in fuser Debian #502208
  * pstree man page mentions -Z may not be available Debian #478327
  * pstree handles UTF-8 lengths much better Debian #413503
  * killall says no process found when process not found Debian #500097
  * pstree makes a bigger buffer for -al flags Debian #352603
  * Dynamically reallocate buffer for fuser patch from Don Armstrong
  * Updated Indonesian PO file
  * peekfd off by one problem in fds Debian #460530
  * Patch from Marcus Watts for better comm handling in pstree
  * Updated Hungarian po file
  * Updated French and German po files
  * Fuser -m detects more open sockets SF patch #1728412 Thnks marienz
  * Updated Italian, Chinese simplified, Dutch, Swedish and Polish po files
  * Removed old fuser
- Adapt our patches
* Fri Mar 27 2009 werner@suse.de
- nfs4fuser: do not match on shadow mounts
- resolve some memory leaks in fuser
* Thu Mar 12 2009 werner@suse.de
- nfs4fuser: be able to detect the root file system (bnc#464295)
* Wed Mar 11 2009 werner@suse.de
- nfs4fuser: make sure not to stumble on short named mount points
  to avoid to terminate processes on wrong mount points
* Thu Oct  9 2008 werner@suse.de
- Make compiler happy: Don't compare pointer with zero (bnc#432986)
* Wed Oct  1 2008 werner@suse.de
- Avoid stat(2) for all network based file systems (bnc#409011)
* Tue Sep 23 2008 werner@suse.de
- Enhance NFS patch for fuser (bug #409011)
* Mon Sep  1 2008 werner@suse.de
- Do not leak on /proc/net/unix (bnc#417841)
- Read /proc/net/unix and /proc/mounts only once
* Fri Aug 22 2008 prusnak@suse.cz
- enabled SELinux support [Fate#303662]
* Thu Aug  7 2008 werner@suse.de
- Refine NFS patch
- Add option -w for killing only procs with write access
* Fri May 16 2008 werner@suse.de
- Add a warning about fusers option -m due NFS locks
- Strip @ symbol from file names read from /proc/net/unix
* Wed Dec 19 2007 werner@suse.de
- Enhance NFS patch for fuser (bug #346776)
* Fri Dec 14 2007 werner@suse.de
- Update to psmisc-22.6
  * killall.1 mentions you can use -SIGxxx as well as just -XXX for
    signal Debian #431082
  * Added support for PPC architecture for peekfd
  * Updated the Chinese simplified po file
  * Added support for x86_64 architecture for peekfd
  * Added Chinese simplified po file
  * Updated Dutch, Vietnamese, Polish and Italian translations
  * Patch for peekfd from Benno Schulenberg
  * Fixed up NLS for fuser, patch from Benno Schulenberg
  * killall asks for Signal (procname) if not SIGTERM
* Thu Oct  4 2007 bg@suse.de
- Disable peekfd on hppa
* Thu Apr 26 2007 werner@suse.de
- Args, peekfd is ix86 specific, disable on other architectures
* Thu Apr 26 2007 werner@suse.de
- Update to psmisc-22.5
  * fuser tcp works on 64bit
  * Added new tool peekfd
  * killall uses /proc/<pid>/exe if inode comparision fails
  * fuser correctly parses remote tcp ports
- Patched fuser to avoid to be locked on stalled NFS (bug #166912)
* Thu Mar 29 2007 rguenther@suse.de
- Add ncurses-devel BuildRequires
* Fri Sep 15 2006 werner@suse.de
- Update to psmisc version 22.3 which includes the previous fixes
* Wed Feb  8 2006 max@suse.de
- Fix exit code of fuser in silent mode [#148563].
* Fri Jan 27 2006 mmj@suse.de
- Fix finding AF_UNIX sockets [#142342]
- Fix minor nits with net_*
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 mmj@suse.de
- Update to psmisc-22.1 including:
  * Updated PO files
  * fuser signals eg -INT work better
  * removed space out of fuser man page for -signal
  * fuser -s flag works
  * fix grep lines in Makefile for i386 arches
* Fri Dec 16 2005 mmj@suse.de
- update to psmisc-21.9 including:
  * Fixed install-exec-hook so only symlink pstree.x11 if file does
    not exist already.
  * buffer overflow in killall scanf removed
  * Fixed segfault in pstree -a
  * fuser can not use IPv6, for things like uClibc
  * configure has --disable-ipv6 for above
  * fuser finds unix sockets
  * fixed print_matches to only print unmatched objects if -a is
    specified and to output the header for -v
  * fixed argument parsing to handle groups like -av again
* Fri Dec  9 2005 ro@suse.de
- disable selinux
* Tue Nov  8 2005 mmj@suse.de
- add patch to fix print_matches and commandline arguments parsing
* Sun Nov  6 2005 mmj@suse.de
- fuser returns 1 if no match found like before [#132180]
* Tue Nov  1 2005 mmj@suse.de
- Update to psmisc-21.7
* Mon Aug  8 2005 meissner@suse.de
- fixed buffer overflow in -k failure case with pids >= 10000
* Mon Aug 16 2004 garloff@suse.de
- Update to psmisc-21.5:
  * bugs fixed: UTF-8 line truncation (SF#757164), ss_family
    (SF#845292), docu (fuser, ...)
  * POSIX compat: -m option, ignore -f, fuser output, case
    insensitive options for -I.
  * Cleanups: dev_t and ino_t usage, automake update
  * pstree -A(SCII) flag
- Rediff patches.
* Tue Jul 20 2004 schwab@suse.de
- Use autoreconf.
* Sun Apr  4 2004 kukuk@suse.de
- Add split alias [Bug #38279]
* Sun Feb 15 2004 stepan@suse.de
- update to v21.4
* Sat Feb 14 2004 kukuk@suse.de
- Split from ps package
